@@ -6,7 +6,7 @@
 # | |_| | | (_| | | | \__ \  __/ | | | |_| \__ \  |    | `-#######/
 # \__|_|  \__,_|_| |_|___/\___|_| |_|\__|_|___/  |____|    `- # /
 #
-# Copyright (c) 2018 transentis labs GmbH
+# Copyright (c) 2023 transentis labs GmbH
 # MIT License
 
 
@@ -90,11 +90,13 @@ class ScenarioManagerFactory():
 
                 if scenario_manager_name not in self.scenario_managers:
                     self.scenario_managers[scenario_manager_name] = ScenarioManagerHybrid(
-                        model_dictionary[scenario_manager_name],
-                        scenario_manager_name, model=model)
+                        json_config=model_dictionary[scenario_manager_name],
+                        name=scenario_manager_name, filenames=[filename], model=model)
                     self.scenario_managers[scenario_manager_name].instantiate_model()
                 else:
                     self.scenario_managers[scenario_manager_name].add_scenarios(model_dictionary[scenario_manager_name]["scenarios"])
+                    if filename not in self.scenario_managers[scenario_manager_name].filenames: 
+                        self.scenario_managers[scenario_manager_name]+=[filename]
 
             # HANDLE SD SCENARIOS _ COMPLEX STUFF WITH ALL THE BASE CONSTANTS / BASE POINTS AND POSSIBLE DISTRIBUTION OVER FILES
             else:
